summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/libc/gen/syslog_r.c6
-rw-r--r--lib/libc/hidden/syslog.h7
-rw-r--r--lib/libc/shlib_version4
-rw-r--r--lib/libc/sys/Makefile.inc4
-rw-r--r--lib/libc/sys/sendsyslog.219
-rw-r--r--lib/libc/sys/stack_protector.c4
-rw-r--r--lib/librthread/shlib_version4
-rw-r--r--libexec/ld.so/alpha/ldasm.S4
-rw-r--r--libexec/ld.so/alpha/syscall.h4
-rw-r--r--libexec/ld.so/amd64/ldasm.S4
-rw-r--r--libexec/ld.so/amd64/syscall.h4
-rw-r--r--libexec/ld.so/arm/ldasm.S4
-rw-r--r--libexec/ld.so/arm/syscall.h4
-rw-r--r--libexec/ld.so/hppa/ldasm.S8
-rw-r--r--libexec/ld.so/hppa/syscall.h4
-rw-r--r--libexec/ld.so/i386/ldasm.S4
-rw-r--r--libexec/ld.so/i386/syscall.h4
-rw-r--r--libexec/ld.so/m88k/ldasm.S4
-rw-r--r--libexec/ld.so/m88k/syscall.h4
-rw-r--r--libexec/ld.so/mips64/ldasm.S4
-rw-r--r--libexec/ld.so/mips64/syscall.h4
-rw-r--r--libexec/ld.so/powerpc/ldasm.S4
-rw-r--r--libexec/ld.so/powerpc/syscall.h4
-rw-r--r--libexec/ld.so/sh/ldasm.S4
-rw-r--r--libexec/ld.so/sh/syscall.h4
-rw-r--r--libexec/ld.so/sparc/ldasm.S10
-rw-r--r--libexec/ld.so/sparc/syscall.h4
-rw-r--r--libexec/ld.so/sparc64/ldasm.S6
-rw-r--r--libexec/ld.so/sparc64/syscall.h4
-rw-r--r--libexec/ld.so/util.c4
-rw-r--r--sys/kern/init_sysent.c10
-rw-r--r--sys/kern/kern_pledge.c4
-rw-r--r--sys/kern/subr_log.c14
-rw-r--r--sys/kern/syscalls.c6
-rw-r--r--sys/kern/syscalls.master6
-rw-r--r--sys/sys/syscall.h10
-rw-r--r--sys/sys/syscallargs.h10
37 files changed, 100 insertions, 112 deletions
diff --git a/lib/libc/hidden/syslog.h b/lib/libc/hidden/syslog.h
index 256120d48f5..d0c3ae9ea1c 100644
--- a/lib/libc/hidden/syslog.h
+++ b/lib/libc/hidden/syslog.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syslog.h,v 1.3 2015/11/25 00:01:21 deraadt Exp $ */
+/* $OpenBSD: syslog.h,v 1.4 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 2015 Philip Guenther <guenther@openbsd.org>
*
@@ -20,12 +20,9 @@
#include_next <syslog.h>
-int sendsyslog(const char *, __size_t);
+int sendsyslog(const char *, __size_t, int);
PROTO_NORMAL(sendsyslog);
-int sendsyslog2(const char *, __size_t, int);
-PROTO_NORMAL(sendsyslog2);
-
__BEGIN_HIDDEN_DECLS
void __vsyslog_r(int, struct syslog_data *, int,
const char *, __va_list);
diff --git a/lib/libc/shlib_version b/lib/libc/shlib_version
index 19127031a94..ace8600e544 100644
--- a/lib/libc/shlib_version
+++ b/lib/libc/shlib_version
@@ -1,4 +1,4 @@
-major=84
-minor=3
+major=85
+minor=0
# note: If changes were made to include/thread_private.h or if system
# calls were added/changed then librthread/shlib_version also be updated.
diff --git a/lib/libc/sys/Makefile.inc b/lib/libc/sys/Makefile.inc
index c2ef3ca72ee..19dc9667548 100644
--- a/lib/libc/sys/Makefile.inc
+++ b/lib/libc/sys/Makefile.inc
@@ -1,4 +1,4 @@
-# $OpenBSD: Makefile.inc,v 1.137 2015/11/25 00:01:21 deraadt Exp $
+# $OpenBSD: Makefile.inc,v 1.138 2016/03/21 22:41:28 bluhm Exp $
# $NetBSD: Makefile.inc,v 1.35 1995/10/16 23:49:07 jtc Exp $
# @(#)Makefile.inc 8.1 (Berkeley) 6/17/93
@@ -51,7 +51,7 @@ ASM= __get_tcb.o __getcwd.o __semctl.o __set_tcb.o __syscall.o \
quotactl.o read.o readlink.o readlinkat.o readv.o reboot.o \
recvfrom.o recvmsg.o rename.o renameat.o revoke.o rmdir.o \
sched_yield.o select.o semget.o semop.o sendmsg.o sendsyslog.o \
- sendsyslog2.o sendto.o \
+ sendto.o \
setegid.o seteuid.o setgid.o setgroups.o setitimer.o \
setpgid.o setpriority.o setregid.o setresgid.o setresuid.o \
setreuid.o setrlimit.o setrtable.o setsid.o setsockopt.o \
diff --git a/lib/libc/sys/sendsyslog.2 b/lib/libc/sys/sendsyslog.2
index 5761df3d031..3626662c1e5 100644
--- a/lib/libc/sys/sendsyslog.2
+++ b/lib/libc/sys/sendsyslog.2
@@ -1,4 +1,4 @@
-.\" $OpenBSD: sendsyslog.2,v 1.5 2016/02/22 22:22:30 bluhm Exp $
+.\" $OpenBSD: sendsyslog.2,v 1.6 2016/03/21 22:41:28 bluhm Exp $
.\"
.\" Copyright (c) 2014 Theo de Raadt
.\"
@@ -14,26 +14,21 @@
.\" ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
.\"
-.Dd $Mdocdate: February 22 2016 $
+.Dd $Mdocdate: March 21 2016 $
.Dt SENDSYSLOG 2
.Os
.Sh NAME
.Nm sendsyslog ,
-.Nm sendsyslog2
.Nd send a message to syslogd
.Sh SYNOPSIS
.In sys/syslog.h
.In sys/types.h
.Ft int
-.Fn sendsyslog "const void *msg" "size_t len"
-.Ft int
-.Fn sendsyslog2 "const void *msg" "size_t len" "int flags"
+.Fn sendsyslog "const void *msg" "size_t len" "int flags"
.Sh DESCRIPTION
The
.Fn sendsyslog
-and
-.Fn sendsyslog2
-functions are used to transmit a
+functions is used to transmit a
.Xr syslog 3
formatted message direct to
.Xr syslogd 8
@@ -42,7 +37,7 @@ without requiring the allocation of a socket.
The
.Fa flags
argument of
-.Fn sendsyslog2
+.Fn sendsyslog
accepts the
.Dv LOG_CONS
flag.
@@ -74,7 +69,3 @@ The
.Fn sendsyslog
function call appeared in
.Ox 5.6 .
-The
-.Fn sendsyslog2
-function call appeared in
-.Ox 5.9 .
diff --git a/lib/libc/sys/stack_protector.c b/lib/libc/sys/stack_protector.c
index b1b07c2beda..116aecd316a 100644
--- a/lib/libc/sys/stack_protector.c
+++ b/lib/libc/sys/stack_protector.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: stack_protector.c,v 1.22 2016/03/13 18:34:21 guenther Exp $ */
+/* $OpenBSD: stack_protector.c,v 1.23 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 2002 Hiroaki Etoh, Federico G. Schwindt, and Miodrag Vallat.
@@ -68,7 +68,7 @@ __stack_smash_handler(const char func[], int damaged)
strlcat(buf, ": stack overflow in function ", sizeof buf);
strlcat(buf, func, sizeof buf);
- sendsyslog2(buf, strlen(buf), LOG_CONS);
+ sendsyslog(buf, strlen(buf), LOG_CONS);
memset(&sa, 0, sizeof(sa));
sigemptyset(&sa.sa_mask);
diff --git a/lib/librthread/shlib_version b/lib/librthread/shlib_version
index dc34974a494..83b24802061 100644
--- a/lib/librthread/shlib_version
+++ b/lib/librthread/shlib_version
@@ -1,2 +1,2 @@
-major=20
-minor=1
+major=21
+minor=0
diff --git a/libexec/ld.so/alpha/ldasm.S b/libexec/ld.so/alpha/ldasm.S
index 2c947fd7bc2..f71de97c74d 100644
--- a/libexec/ld.so/alpha/ldasm.S
+++ b/libexec/ld.so/alpha/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.33 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.34 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -313,7 +313,7 @@ DL_SYSCALL(fstat)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(getdents)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL(gettimeofday)
DL_SYSCALL_NOERR(issetugid)
diff --git a/libexec/ld.so/alpha/syscall.h b/libexec/ld.so/alpha/syscall.h
index e0024634eeb..df364c4715e 100644
--- a/libexec/ld.so/alpha/syscall.h
+++ b/libexec/ld.so/alpha/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.31 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.32 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/amd64/ldasm.S b/libexec/ld.so/amd64/ldasm.S
index 0f714ec311d..2dc0fe096ed 100644
--- a/libexec/ld.so/amd64/ldasm.S
+++ b/libexec/ld.so/amd64/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.22 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.23 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2002,2004 Dale Rahn
@@ -96,7 +96,7 @@ DL_SYSCALL(readlink)
DL_SYSCALL(lstat)
DL_SYSCALL(utrace)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL2(set_tcb,__set_tcb)
diff --git a/libexec/ld.so/amd64/syscall.h b/libexec/ld.so/amd64/syscall.h
index 2991b9b34d8..26ebf6c4092 100644
--- a/libexec/ld.so/amd64/syscall.h
+++ b/libexec/ld.so/amd64/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.19 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.20 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/arm/ldasm.S b/libexec/ld.so/arm/ldasm.S
index fa0b58fd455..36f1ab62bc2 100644
--- a/libexec/ld.so/arm/ldasm.S
+++ b/libexec/ld.so/arm/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.20 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.21 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2004 Dale Rahn
@@ -125,7 +125,7 @@ DL_SYSCALL(readlink)
DL_SYSCALL(lstat)
DL_SYSCALL(utrace)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(sysctl)
diff --git a/libexec/ld.so/arm/syscall.h b/libexec/ld.so/arm/syscall.h
index 788ebfc9715..d9ecc3b2c3a 100644
--- a/libexec/ld.so/arm/syscall.h
+++ b/libexec/ld.so/arm/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.19 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.20 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/hppa/ldasm.S b/libexec/ld.so/hppa/ldasm.S
index 536f9304bf0..59e5902e676 100644
--- a/libexec/ld.so/hppa/ldasm.S
+++ b/libexec/ld.so/hppa/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.19 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.20 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2004 Michael Shalayeff
@@ -272,11 +272,11 @@ ENTRY(_dl_getentropy,0)
nop
EXIT(_dl_getentropy)
-ENTRY(_dl_sendsyslog2,0)
- SYSCALL(sendsyslog2)
+ENTRY(_dl_sendsyslog,0)
+ SYSCALL(sendsyslog)
bv r0(rp)
nop
-EXIT(_dl_sendsyslog2)
+EXIT(_dl_sendsyslog)
ENTRY(_dl_pledge,0)
SYSCALL(pledge)
diff --git a/libexec/ld.so/hppa/syscall.h b/libexec/ld.so/hppa/syscall.h
index 2991b9b34d8..26ebf6c4092 100644
--- a/libexec/ld.so/hppa/syscall.h
+++ b/libexec/ld.so/hppa/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.19 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.20 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/i386/ldasm.S b/libexec/ld.so/i386/ldasm.S
index cb0cac0a40a..86c5f0d7376 100644
--- a/libexec/ld.so/i386/ldasm.S
+++ b/libexec/ld.so/i386/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.24 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.25 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2002 Dale Rahn
@@ -121,7 +121,7 @@ DL_SYSCALL(readlink)
DL_SYSCALL(lstat)
DL_SYSCALL(utrace)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(sysctl)
diff --git a/libexec/ld.so/i386/syscall.h b/libexec/ld.so/i386/syscall.h
index 42ec3675f3a..811c8acbdae 100644
--- a/libexec/ld.so/i386/syscall.h
+++ b/libexec/ld.so/i386/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.23 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.24 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/m88k/ldasm.S b/libexec/ld.so/m88k/ldasm.S
index 91c051cae59..c5ce9333855 100644
--- a/libexec/ld.so/m88k/ldasm.S
+++ b/libexec/ld.so/m88k/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.17 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.18 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2013 Miodrag Vallat.
@@ -209,7 +209,7 @@ DL_SYSCALL(utrace)
DL_SYSCALL(getentropy)
jmp %r1
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
jmp %r1
DL_SYSCALL(pledge)
diff --git a/libexec/ld.so/m88k/syscall.h b/libexec/ld.so/m88k/syscall.h
index c88ceb92173..f67e610c9d2 100644
--- a/libexec/ld.so/m88k/syscall.h
+++ b/libexec/ld.so/m88k/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.15 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.16 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/mips64/ldasm.S b/libexec/ld.so/mips64/ldasm.S
index dae54a722f4..ec2e63e06af 100644
--- a/libexec/ld.so/mips64/ldasm.S
+++ b/libexec/ld.so/mips64/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.17 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.18 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 1998-2002 Opsycon AB, Sweden.
@@ -151,7 +151,7 @@ DL_SYSCALL(fstat)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(getdents)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL(gettimeofday)
DL_SYSCALL_NOERR(issetugid)
diff --git a/libexec/ld.so/mips64/syscall.h b/libexec/ld.so/mips64/syscall.h
index bd94519d300..30fe1458a98 100644
--- a/libexec/ld.so/mips64/syscall.h
+++ b/libexec/ld.so/mips64/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.21 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.22 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 1998-2002 Opsycon AB, Sweden.
@@ -56,7 +56,7 @@ long _dl__syscall(quad_t, ...);
int _dl_sysctl(const int *, u_int, void *, size_t *, void *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fd, off_t offset, int whence)
diff --git a/libexec/ld.so/powerpc/ldasm.S b/libexec/ld.so/powerpc/ldasm.S
index ab8a9c487a7..0b2c9753d58 100644
--- a/libexec/ld.so/powerpc/ldasm.S
+++ b/libexec/ld.so/powerpc/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.27 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.28 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 1999 Dale Rahn
@@ -147,7 +147,7 @@ DL_SYSCALL(fstat)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(getdents)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL(gettimeofday)
DL_SYSCALL_NOERR(issetugid)
diff --git a/libexec/ld.so/powerpc/syscall.h b/libexec/ld.so/powerpc/syscall.h
index 3f9edb3b1b9..24da619b6eb 100644
--- a/libexec/ld.so/powerpc/syscall.h
+++ b/libexec/ld.so/powerpc/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.39 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.40 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 1998 Per Fogelstrom, Opsycon AB
@@ -58,7 +58,7 @@ int _dl_sysctl(const int *, u_int, void *, size_t *, void *, size_t);
int _dl_utrace(const char *, const void *, size_t);
ssize_t _dl_write(int, const char *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/sh/ldasm.S b/libexec/ld.so/sh/ldasm.S
index 9016c8dd9aa..cafd90ea8f8 100644
--- a/libexec/ld.so/sh/ldasm.S
+++ b/libexec/ld.so/sh/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.22 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.23 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2006 Dale Rahn
@@ -190,7 +190,7 @@ DL_SYSCALL(readlink)
DL_SYSCALL(lstat)
DL_SYSCALL(utrace)
DL_SYSCALL(getentropy)
-DL_SYSCALL(sendsyslog2)
+DL_SYSCALL(sendsyslog)
DL_SYSCALL(pledge)
DL_SYSCALL2(getcwd,__getcwd)
DL_SYSCALL(sysctl)
diff --git a/libexec/ld.so/sh/syscall.h b/libexec/ld.so/sh/syscall.h
index 1e4146c00cb..e5069e066af 100644
--- a/libexec/ld.so/sh/syscall.h
+++ b/libexec/ld.so/sh/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.17 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.18 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/sparc/ldasm.S b/libexec/ld.so/sparc/ldasm.S
index bf41310d9d0..3bcf14814fd 100644
--- a/libexec/ld.so/sparc/ldasm.S
+++ b/libexec/ld.so/sparc/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.29 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.30 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Jason L. Wright (jason@thought.net)
@@ -355,10 +355,10 @@ _dl_getentropy:
.section ".text"
.align 4
- .global _dl_sendsyslog2
- .type _dl_sendsyslog2,@function
-_dl_sendsyslog2:
- mov SYS_sendsyslog2 | SYSCALL_G2RFLAG, %g1 ! calling sys_sendsyslog
+ .global _dl_sendsyslog
+ .type _dl_sendsyslog,@function
+_dl_sendsyslog:
+ mov SYS_sendsyslog | SYSCALL_G2RFLAG, %g1 ! calling sys_sendsyslog
add %o7, 8, %g2 ! just return on success
t ST_SYSCALL ! off to wonderland
retl
diff --git a/libexec/ld.so/sparc/syscall.h b/libexec/ld.so/sparc/syscall.h
index 5d5c40c29b3..df5293ba4ea 100644
--- a/libexec/ld.so/sparc/syscall.h
+++ b/libexec/ld.so/sparc/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.24 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.25 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/sparc64/ldasm.S b/libexec/ld.so/sparc64/ldasm.S
index 0fa5f65af49..47949f6d7c5 100644
--- a/libexec/ld.so/sparc64/ldasm.S
+++ b/libexec/ld.so/sparc64/ldasm.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: ldasm.S,v 1.41 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: ldasm.S,v 1.42 2016/03/21 22:41:29 bluhm Exp $ */
/* $NetBSD: rtld_start.S,v 1.5 2001/08/14 22:17:48 eeh Exp $ */
/*
@@ -335,8 +335,8 @@ _ENTRY(_dl_getentropy)
retl
sub %g0, %o0, %o0 ! error: result = -errno
-_ENTRY(_dl_sendsyslog2)
- mov SYS_sendsyslog2 | SYSCALL_G2RFLAG, %g1 ! calling sys_sendsyslog
+_ENTRY(_dl_sendsyslog)
+ mov SYS_sendsyslog | SYSCALL_G2RFLAG, %g1 ! calling sys_sendsyslog
add %o7, 8, %g2 ! just return on success
t ST_SYSCALL ! off to wonderland
retl
diff --git a/libexec/ld.so/sparc64/syscall.h b/libexec/ld.so/sparc64/syscall.h
index f667ceefd69..0abb05b7314 100644
--- a/libexec/ld.so/sparc64/syscall.h
+++ b/libexec/ld.so/sparc64/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.31 2016/03/21 01:32:49 guenther Exp $ */
+/* $OpenBSD: syscall.h,v 1.32 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2001 Niklas Hallqvist
@@ -57,7 +57,7 @@ int _dl_lstat(const char *, struct stat *);
int _dl_getcwd(char *, size_t);
int _dl_utrace(const char *, const void *, size_t);
int _dl_getentropy(char *, size_t);
-int _dl_sendsyslog2(const char *, size_t, int);
+int _dl_sendsyslog(const char *, size_t, int);
static inline off_t
_dl_lseek(int fildes, off_t offset, int whence)
diff --git a/libexec/ld.so/util.c b/libexec/ld.so/util.c
index e8fb1295f22..ebf33e071b2 100644
--- a/libexec/ld.so/util.c
+++ b/libexec/ld.so/util.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: util.c,v 1.40 2016/03/21 01:32:48 guenther Exp $ */
+/* $OpenBSD: util.c,v 1.41 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 1998 Per Fogelstrom, Opsycon AB
@@ -54,7 +54,7 @@ __stack_smash_handler(char func[], int damaged)
_dl_strlcat(message, "stack overflow in function ", sizeof message);
_dl_strlcat(message, func, sizeof message);
- _dl_sendsyslog2(message, _dl_strlen(message), LOG_CONS);
+ _dl_sendsyslog(message, _dl_strlen(message), LOG_CONS);
_dl_exit(127);
}
diff --git a/sys/kern/init_sysent.c b/sys/kern/init_sysent.c
index e29de20d869..40e2300c392 100644
--- a/sys/kern/init_sysent.c
+++ b/sys/kern/init_sysent.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: init_sysent.c,v 1.179 2015/11/24 23:50:50 deraadt Exp $ */
+/* $OpenBSD: init_sysent.c,v 1.180 2016/03/21 22:41:29 bluhm Exp $ */
/*
* System call switch table.
@@ -198,8 +198,8 @@ struct sysent sysent[] = {
sys_getpgrp }, /* 81 = getpgrp */
{ 2, s(struct sys_setpgid_args), 0,
sys_setpgid }, /* 82 = setpgid */
- { 2, s(struct sys_sendsyslog_args), 0,
- sys_sendsyslog }, /* 83 = sendsyslog */
+ { 2, s(struct sys_osendsyslog_args), 0,
+ sys_osendsyslog }, /* 83 = osendsyslog */
{ 4, s(struct sys_utimensat_args), 0,
sys_utimensat }, /* 84 = utimensat */
{ 2, s(struct sys_futimens_args), 0,
@@ -256,8 +256,8 @@ struct sysent sysent[] = {
sys_pselect }, /* 110 = pselect */
{ 1, s(struct sys_sigsuspend_args), 0,
sys_sigsuspend }, /* 111 = sigsuspend */
- { 3, s(struct sys_sendsyslog2_args), 0,
- sys_sendsyslog2 }, /* 112 = sendsyslog2 */
+ { 3, s(struct sys_sendsyslog_args), 0,
+ sys_sendsyslog }, /* 112 = sendsyslog */
{ 0, 0, 0,
sys_nosys }, /* 113 = obsolete orecvmsg */
{ 0, 0, 0,
diff --git a/sys/kern/kern_pledge.c b/sys/kern/kern_pledge.c
index 1c711883fdf..9c22ad8a6c2 100644
--- a/sys/kern/kern_pledge.c
+++ b/sys/kern/kern_pledge.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: kern_pledge.c,v 1.158 2016/03/16 06:46:39 ratchov Exp $ */
+/* $OpenBSD: kern_pledge.c,v 1.159 2016/03/21 22:41:29 bluhm Exp $ */
/*
* Copyright (c) 2015 Nicholas Marriott <nicm@openbsd.org>
@@ -108,7 +108,7 @@ const uint64_t pledge_syscalls[SYS_MAXSYSCALL] = {
[SYS___get_tcb] = PLEDGE_ALWAYS,
[SYS_pledge] = PLEDGE_ALWAYS,
[SYS_sendsyslog] = PLEDGE_ALWAYS, /* stack protector reporting */
- [SYS_sendsyslog2] = PLEDGE_ALWAYS, /* stack protector reporting */
+ [SYS_osendsyslog] = PLEDGE_ALWAYS, /* obsolete sendsyslog */
[SYS_thrkill] = PLEDGE_ALWAYS, /* raise, abort, stack pro */
[SYS_utrace] = PLEDGE_ALWAYS, /* ltrace(1) from ld.so */
diff --git a/sys/kern/subr_log.c b/sys/kern/subr_log.c
index 27dcc512c75..7ecdfa9185a 100644
--- a/sys/kern/subr_log.c
+++ b/sys/kern/subr_log.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: subr_log.c,v 1.37 2016/01/13 17:05:25 stefan Exp $ */
+/* $OpenBSD: subr_log.c,v 1.38 2016/03/21 22:41:29 bluhm Exp $ */
/* $NetBSD: subr_log.c,v 1.11 1996/03/30 22:24:44 christos Exp $ */
/*
@@ -349,24 +349,24 @@ logioctl(dev_t dev, u_long com, caddr_t data, int flag, struct proc *p)
}
int
-sys_sendsyslog(struct proc *p, void *v, register_t *retval)
+sys_osendsyslog(struct proc *p, void *v, register_t *retval)
{
- struct sys_sendsyslog_args /* {
+ struct sys_osendsyslog_args /* {
syscallarg(const void *) buf;
syscallarg(size_t) nbyte;
} */ *uap = v;
- struct sys_sendsyslog2_args oap;
+ struct sys_sendsyslog_args oap;
SCARG(&oap, buf) = SCARG(uap, buf);
SCARG(&oap, nbyte) = SCARG(uap, nbyte);
SCARG(&oap, flags) = 0;
- return sys_sendsyslog2(p, &oap, retval);
+ return sys_sendsyslog(p, &oap, retval);
}
int
-sys_sendsyslog2(struct proc *p, void *v, register_t *retval)
+sys_sendsyslog(struct proc *p, void *v, register_t *retval)
{
- struct sys_sendsyslog2_args /* {
+ struct sys_sendsyslog_args /* {
syscallarg(const void *) buf;
syscallarg(size_t) nbyte;
syscallarg(int) flags;
diff --git a/sys/kern/syscalls.c b/sys/kern/syscalls.c
index 426ddaa65af..a230c9b59e7 100644
--- a/sys/kern/syscalls.c
+++ b/sys/kern/syscalls.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscalls.c,v 1.178 2015/11/24 23:50:50 deraadt Exp $ */
+/* $OpenBSD: syscalls.c,v 1.179 2016/03/21 22:41:29 bluhm Exp $ */
/*
* System call names.
@@ -103,7 +103,7 @@ char *syscallnames[] = {
"setgroups", /* 80 = setgroups */
"getpgrp", /* 81 = getpgrp */
"setpgid", /* 82 = setpgid */
- "sendsyslog", /* 83 = sendsyslog */
+ "osendsyslog", /* 83 = osendsyslog */
"utimensat", /* 84 = utimensat */
"futimens", /* 85 = futimens */
"kbind", /* 86 = kbind */
@@ -132,7 +132,7 @@ char *syscallnames[] = {
"ppoll", /* 109 = ppoll */
"pselect", /* 110 = pselect */
"sigsuspend", /* 111 = sigsuspend */
- "sendsyslog2", /* 112 = sendsyslog2 */
+ "sendsyslog", /* 112 = sendsyslog */
"#113 (obsolete orecvmsg)", /* 113 = obsolete orecvmsg */
"#114 (obsolete osendmsg)", /* 114 = obsolete osendmsg */
"#115 (obsolete vtrace)", /* 115 = obsolete vtrace */
diff --git a/sys/kern/syscalls.master b/sys/kern/syscalls.master
index 117b7bdbad0..dcf18dcb8ac 100644
--- a/sys/kern/syscalls.master
+++ b/sys/kern/syscalls.master
@@ -1,4 +1,4 @@
-; $OpenBSD: syscalls.master,v 1.166 2015/11/24 23:47:17 deraadt Exp $
+; $OpenBSD: syscalls.master,v 1.167 2016/03/21 22:41:29 bluhm Exp $
; $NetBSD: syscalls.master,v 1.32 1996/04/23 10:24:21 mycroft Exp $
; @(#)syscalls.master 8.2 (Berkeley) 1/13/94
@@ -186,7 +186,7 @@
const gid_t *gidset); }
81 STD { int sys_getpgrp(void); }
82 STD { int sys_setpgid(pid_t pid, pid_t pgid); }
-83 STD { int sys_sendsyslog(const void *buf, size_t nbyte); }
+83 STD { int sys_osendsyslog(const void *buf, size_t nbyte); }
84 STD { int sys_utimensat(int fd, const char *path, \
const struct timespec *times, int flag); }
85 STD { int sys_futimens(int fd, \
@@ -233,7 +233,7 @@
fd_set *ex, const struct timespec *ts, \
const sigset_t *mask); }
111 STD { int sys_sigsuspend(int mask); }
-112 STD { int sys_sendsyslog2(const void *buf, size_t nbyte, \
+112 STD { int sys_sendsyslog(const void *buf, size_t nbyte, \
int flags); }
113 OBSOL orecvmsg
114 OBSOL osendmsg
diff --git a/sys/sys/syscall.h b/sys/sys/syscall.h
index 101c1cf0beb..f9cf6faf2e7 100644
--- a/sys/sys/syscall.h
+++ b/sys/sys/syscall.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscall.h,v 1.177 2015/11/24 23:50:50 deraadt Exp $ */
+/* $OpenBSD: syscall.h,v 1.178 2016/03/21 22:41:29 bluhm Exp $ */
/*
* System call numbers.
@@ -256,8 +256,8 @@
/* syscall: "setpgid" ret: "int" args: "pid_t" "pid_t" */
#define SYS_setpgid 82
-/* syscall: "sendsyslog" ret: "int" args: "const void *" "size_t" */
-#define SYS_sendsyslog 83
+/* syscall: "osendsyslog" ret: "int" args: "const void *" "size_t" */
+#define SYS_osendsyslog 83
/* syscall: "utimensat" ret: "int" args: "int" "const char *" "const struct timespec *" "int" */
#define SYS_utimensat 84
@@ -343,8 +343,8 @@
/* syscall: "sigsuspend" ret: "int" args: "int" */
#define SYS_sigsuspend 111
-/* syscall: "sendsyslog2" ret: "int" args: "const void *" "size_t" "int" */
-#define SYS_sendsyslog2 112
+/* syscall: "sendsyslog" ret: "int" args: "const void *" "size_t" "int" */
+#define SYS_sendsyslog 112
/* 113 is obsolete orecvmsg */
/* 114 is obsolete osendmsg */
diff --git a/sys/sys/syscallargs.h b/sys/sys/syscallargs.h
index 15352feabdc..d8457312006 100644
--- a/sys/sys/syscallargs.h
+++ b/sys/sys/syscallargs.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: syscallargs.h,v 1.180 2015/11/24 23:50:50 deraadt Exp $ */
+/* $OpenBSD: syscallargs.h,v 1.181 2016/03/21 22:41:29 bluhm Exp $ */
/*
* System call argument lists.
@@ -401,7 +401,7 @@ struct sys_setpgid_args {
syscallarg(pid_t) pgid;
};
-struct sys_sendsyslog_args {
+struct sys_osendsyslog_args {
syscallarg(const void *) buf;
syscallarg(size_t) nbyte;
};
@@ -569,7 +569,7 @@ struct sys_sigsuspend_args {
syscallarg(int) mask;
};
-struct sys_sendsyslog2_args {
+struct sys_sendsyslog_args {
syscallarg(const void *) buf;
syscallarg(size_t) nbyte;
syscallarg(int) flags;
@@ -1193,7 +1193,7 @@ int sys_getgroups(struct proc *, void *, register_t *);
int sys_setgroups(struct proc *, void *, register_t *);
int sys_getpgrp(struct proc *, void *, register_t *);
int sys_setpgid(struct proc *, void *, register_t *);
-int sys_sendsyslog(struct proc *, void *, register_t *);
+int sys_osendsyslog(struct proc *, void *, register_t *);
int sys_utimensat(struct proc *, void *, register_t *);
int sys_futimens(struct proc *, void *, register_t *);
int sys_kbind(struct proc *, void *, register_t *);
@@ -1222,7 +1222,7 @@ int sys_pledge(struct proc *, void *, register_t *);
int sys_ppoll(struct proc *, void *, register_t *);
int sys_pselect(struct proc *, void *, register_t *);
int sys_sigsuspend(struct proc *, void *, register_t *);
-int sys_sendsyslog2(struct proc *, void *, register_t *);
+int sys_sendsyslog(struct proc *, void *, register_t *);
int sys_getsockopt(struct proc *, void *, register_t *);
int sys_thrkill(struct proc *, void *, register_t *);
int sys_readv(struct proc *, void *, register_t *);
diff --git a/lib/libc/gen/syslog_r.c b/lib/libc/gen/syslog_r.c
index f89107d796f..faa1bcdd8db 100644
--- a/lib/libc/gen/syslog_r.c
+++ b/lib/libc/gen/syslog_r.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: syslog_r.c,v 1.13 2016/03/13 18:34:20 guenther Exp $ */
+/* $OpenBSD: syslog_r.c,v 1.14 2016/03/21 22:41:28 bluhm Exp $ */
/*
* Copyright (c) 1983, 1988, 1993
* The Regents of the University of California. All rights reserved.
@@ -190,10 +190,10 @@ __vsyslog_r(int pri, struct syslog_data *data,
}
/*
* If the sendsyslog2() fails, it means that syslogd
* is not running or the kernel ran out of buffers.
*/
- sendsyslog2(tbuf, cnt, data->log_stat & LOG_CONS);
+ sendsyslog(tbuf, cnt, data->log_stat & LOG_CONS);
}
void
@@ -190,10 +190,10 @@ __vsyslog_r(int pri, struct syslog_data *data,
}
/*
- * If the sendsyslog2() fails, it means that syslogd
+ * If the sendsyslog() fails, it means that syslogd
* is not running or the kernel ran out of buffers.
*/